@@ -11,7 +11,7 @@ from kks.util.common import get_solution_directory, find_test_pairs, format_file
 @click.option('-T', '-tg', '--target', default='default',
               help='Target name to build')
 @click.option('-v', '--verbose', is_flag=True,
-              help='Verbose mode (show used gcc args)')
+              help='Verbose mode (show used compiler args)')
 @click.option('--asan/--no-asan', is_flag=True, default=True,
               help='Use asan (true by default)')  # if there are asan flags for the selected target and '--no-asan' is used, then only flags from the config will be used
 @click.option('-g', '-vg', '--valgrind', is_flag=True,
