@@ -9,7 +9,7 @@ from kks.util.common import find_workspace, find_problem_rootdir, config_directo
 
 target_file = 'targets.yaml'
 
-targets_version = 1
+targets_version = 2
 
 global_comment = '# This is the default config file, it is used in any subdirectory of the workspace.\n'\
                  '# You can modify the default target (the changes will be applied only in this workspace).\n'\
@@ -20,6 +20,7 @@ class Target:
     def __init__(self, name, settings):
         self.name = name
         self.files = settings.get('files')
+        self.compiler = settings.get('compiler')
         self.flags = settings.get('flags')
         self.libs = settings.get('libs')
         self.asm64bit = settings.get('asm64bit')
@@ -28,11 +29,11 @@ class Target:
         # option is not set or the list contains "DEFAULT" as first item
         # if the list is empty, we shouldn't replace it (e.g. if this target excludes all libs)
         self.need_default = any(arr is None or (arr and arr[0] == 'DEFAULT') for arr in [self.files, self.flags, self.libs])\
-                            or self.out is None or self.asm64bit is None
+                            or self.compiler is None or self.out is None or self.asm64bit is None
         # custom default target may still have some fields not set, so we will have to get them from a higher-level config (workspace root or package-provided)
 
     def __str__(self):
-        return f'Target("{self.name}", files={self.files}, flags={self.flags}, libs={self.libs}, asm64bit={self.asm64bit}, out="{self.out}")'
+        return f'Target("{self.name}", compiler="{self.compiler}", flags={self.flags}, files={self.files}, libs={self.libs}, asm64bit={self.asm64bit}, out="{self.out}")'
 
     def replace_macros_add_missing(self, problem, default_target):
         def modify(x):
@@ -46,10 +47,11 @@ class Target:
                 return [modify(e) for e in default + lst[1:]]
             return [modify(e) for e in lst]
 
+        self.compiler = self.compiler or default_target.compiler
         self.files = modify_list(self.files, default_target.files)
         self.flags = modify_list(self.flags, default_target.flags)
         self.libs = modify_list(self.libs, default_target.libs)
-        self.out = modify(self.out) if self.out is not None else default_target.out
+        self.out = modify(self.out) if self.out is not None else default_target.out  # "or" doesn't work
         self.asm64bit = self.asm64bit if self.asm64bit is not None else default_target.asm64bit
 
 
@@ -136,6 +138,7 @@ def find_target(name):
         if root_target.need_default:
             # it makes no sense to look for default in CWD if the target is in workspace root
             default = get_target(root_cfg, 'default') or package_default
+            # TODO optimize? if root_target is "default", then default is "default" and the next condition is always true
             if default.need_default:
                 default.replace_macros_add_missing(problem, package_default)
         root_target.replace_macros_add_missing(problem, default)
